@@ -25,7 +25,7 @@
 #ifndef DEFINES_H
 # define DEFINES_H
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
