@@ -23,7 +23,7 @@
  */
 
 #include "gnutls_int.h"
-#include "gnutls_auth_int.h"
+#include "gnutls_auth.h"
 #include "gnutls_errors.h"
 #include "gnutls_num.h"
 #include <ext_server_name.h>
