@@ -36,7 +36,7 @@
 #include <auth_anon.h>
 #include <auth_cert.h>
 #include <gnutls_errors.h>
-#include <gnutls_auth_int.h>
+#include <gnutls_auth.h>
 #include <gnutls_session_pack.h>
 #include <gnutls_datum.h>
 #include <gnutls_num.h>
