@@ -39,7 +39,7 @@
 #include "gnutls_hash_int.h"
 #include "gnutls_db.h"
 #include "gnutls_extensions.h"
-#include "gnutls_auth_int.h"
+#include "gnutls_auth.h"
 #include "gnutls_v2_compat.h"
 
 /* This selects the best supported ciphersuite from the ones provided */
