@@ -35,7 +35,6 @@
 #include <gnutls_pk.h>
 
 static int _gnutls_asn1_encode_rsa (ASN1_TYPE * c2, bigint_t * params);
-int _gnutls_asn1_encode_dsa (ASN1_TYPE * c2, bigint_t * params);
 
 /* remove this when libgcrypt can handle the PKCS #1 coefficients from
  * rsa keys
@@ -965,7 +964,7 @@ _gnutls_asn1_encode_rsa (ASN1_TYPE * c2, bigint_t * params)
 
   /* Read all the sizes */
   total = 0;
-  for (i = 0; i < 5; i++)
+  for (i = 0; i < RSA_PRIVATE_PARAMS; i++)
     {
       _gnutls_mpi_print_lz (params[i], NULL, &size[i]);
       total += size[i];
