@@ -40,6 +40,7 @@ int main(void)
     gnutls_mac_algorithm_t mac;
     gnutls_protocol_t version;
 
+    printf ("Available cipher suites:\n");
     printf ("@multitable @columnfractions .60 .20 .20\n");
     for (i = 0; (name = gnutls_cipher_suite_info
 		 (i, id, &kx, &cipher, &mac, &version)); i++)
@@ -55,7 +56,7 @@ int main(void)
   {
     const gnutls_certificate_type_t *p = gnutls_certificate_type_list ();
 
-    printf ("\n\nAvailable certificate types: \n@itemize\n");
+    printf ("\n\nAvailable certificate types:\n@itemize\n");
     for (; *p; p++)
       {
 	printf ("@item %s\n", gnutls_certificate_type_get_name (*p));
@@ -107,6 +108,28 @@ int main(void)
     printf ("@end itemize\n");
   }
 
+  {
+    const gnutls_pk_algorithm_t *p = gnutls_pk_list ();
+
+    printf ("\nAvailable public key algorithms:\n@itemize\n");
+    for (; *p; p++)
+      {
+	printf ("@item %s\n", gnutls_pk_get_name (*p));
+      }
+    printf ("@end itemize\n");
+  }
+
+  {
+    const gnutls_sign_algorithm_t *p = gnutls_sign_list ();
+
+    printf ("\nAvailable public key signature algorithms:\n@itemize\n");
+    for (; *p; p++)
+      {
+	printf ("@item %s\n", gnutls_sign_get_name (*p));
+      }
+    printf ("@end itemize\n");
+  }
+
   {
     const gnutls_compression_method_t *p = gnutls_compression_list ();
 
