@@ -9,12 +9,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- *               
+ *
  * GNUTLS is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                               
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -45,6 +45,8 @@ int _win_select (int max_fd, fd_set * rfds, fd_set * wfds, fd_set * efds,
 #endif
 
 #include "error.h"
+#include "progname.h"
+#include "version-etc.h"
 #include "read-file.h"
 
 #include "getaddrinfo.h"
@@ -812,6 +814,8 @@ main (int argc, char **argv)
   struct sockaddr_storage client_address;
   socklen_t calen;
 
+  set_program_name (argv[0]);
+
 #ifndef _WIN32
   signal (SIGPIPE, SIG_IGN);
   signal (SIGHUP, SIG_IGN);
@@ -1420,11 +1424,11 @@ gaa_parser (int argc, char **argv)
 void
 serv_version (void)
 {
-  const char *v = gnutls_check_version (NULL);
-
-  printf ("gnutls-serv (GnuTLS) %s\n", LIBGNUTLS_VERSION);
-  if (strcmp (v, LIBGNUTLS_VERSION) != 0)
-    printf ("libgnutls %s\n", v);
+  const char *p = PACKAGE_NAME;
+  if (strcmp (gnutls_check_version (NULL), PACKAGE_VERSION) != 0)
+    p = PACKAGE_STRING;
+  version_etc (stdout, program_name, p, gnutls_check_version (NULL),
+	       "Nikos Mavrogiannopoulos", (char *) NULL);
 }
 
 /* session resuming support */
@@ -1535,22 +1539,3 @@ wrap_db_delete (void *dbf, gnutls_datum_t key)
   return -1;
 
 }
-
-void
-print_serv_license (void)
-{
-  fputs ("\nCopyright (C) 2001-2003 Paul Sheer, Nikos Mavrogiannopoulos\n"
-	 "\nCopyright (C) 2004 Free Software Foundation\n"
-	 "This program is free software; you can redistribute it and/or modify \n"
-	 "it under the terms of the GNU General Public License as published by \n"
-	 "the Free Software Foundation; either version 3 of the License, or \n"
-	 "(at your option) any later version. \n" "\n"
-	 "This program is distributed in the hope that it will be useful, \n"
-	 "but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
-	 "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
-	 "GNU General Public License for more details. \n" "\n"
-	 "You should have received a copy of the GNU General Public License \n"
-	 "along with this program; if not, write to the Free Software \n"
-	 "Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n\n",
-	 stdout);
-}
